.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###


.. index:: Documentation overview
.. _chap_docoverview:

**********************
Documentation Overview
**********************

For users
=========

* :ref:`Installation Instructions <chap_installation>` (where to obtain it, and
  how to get it running)

.. comment to separate the two lists

* :ref:`Tutorial <chap_tutorial>` (hands-on topics)
* :ref:`Courses <chap_courses>` (course materials)
* :ref:`chap_examples` (batteries included)

.. comment to separate the two lists

* :ref:`User Manual <manual>` [PDF-manual_]
* :ref:`FAQ <chap_faq>` (short answers to common problems)
* :ref:`Module Reference <chap_modref>` (comprehensive reference)
* :ref:`Bibliography <chap_references>` (references to interesting literature)
* :ref:`Development Changelog <chap_changelog>` [:ref:`Movie version
  <chap_code_swarm>`] (see what has changed)

.. _PDF-manual: PyMVPA-Manual.pdf

.. comment to separate the two lists

* :ref:`genindex` (access by keywords)
* :ref:`search` (online and offline full-text search)


For developers
==============

* :ref:`Developer Guidelines <chap_devguide>` [PDF-guide_] (information for people
  contributing code)
* :ref:`Achievements of the first PyMVPA Extravaganza <chap_workshop_2009fall>`
  at Dartmouth College (Nov 30 -- Dec 4 2009)

.. _PDF-guide: PyMVPA-DevGuide.pdf
